==> zen-cart-v1.2.0-l10n-jp-5.zip: zen-cart-v1.2.0-l10n-jp-5/admin/includes/languages/japanese/categories.php <==
<?php
//
// +----------------------------------------------------------------------+
// |zen-cart Open Source E-commerce                                       |
// +----------------------------------------------------------------------+
// | Copyright (c) 2003 The zen-cart developers                           |
// |                                                                      |
// | http://www.zen-cart.com/index.php                                    |
// |                                                                      |
// | Portions Copyright (c) 2003 osCommerce                               |
// +----------------------------------------------------------------------+
// | This source file is subject to version 2.0 of the GPL license,       |
// | that is bundled with this package in the file LICENSE, and is        |
// | available through the world-wide-web at the following url:           |
// | http://www.zen-cart.com/license/2_0.txt.                             |
// | If you did not receive a copy of the zen-cart license and are unable |
// | to obtain it through the world-wide-web, please send a note to       |
// | license@zen-cart.com so we can mail you a copy immediately.          |
// +----------------------------------------------------------------------+
//  $Id: categories.php,v 1.7 2004/12/04 01:58:15 shidairiki Exp $
//

define('HEADING_TITLE', 'ƥꡦʤδ');
define('HEADING_TITLE_GOTO', ':');

define('TABLE_HEADING_ID', 'ID');
define('TABLE_HEADING_CATEGORIES_PRODUCTS', 'ƥ / ');
define('TABLE_HEADING_CATEGORIES_SORT_ORDER', 'Sort');

define('TABLE_HEADING_PRICE','/ò/');
define('TABLE_HEADING_QUANTITY','');

define('TABLE_HEADING_ACTION', '');
define('TABLE_HEADING_STATUS', 'ơ');

define('TEXT_CATEGORIES', 'ƥ:');
define('TEXT_SUBCATEGORIES', '֥ƥ:');
define('TEXT_PRODUCTS', ':');
define('TEXT_PRODUCTS_PRICE_INFO', ':');
define('TEXT_PRODUCTS_TAX_CLASS', 'Ǽ:');
define('TEXT_PRODUCTS_AVERAGE_RATING', 'ʿ:');
define('TEXT_PRODUCTS_QUANTITY_INFO', ':');
define('TEXT_DATE_ADDED', 'Ͽ:');
define('TEXT_DATE_AVAILABLE', 'ȯ:');
define('TEXT_LAST_MODIFIED', ':');
define('TEXT_IMAGE_NONEXISTENT', '¸ߤޤ');
define('TEXT_NO_CHILD_CATEGORIES_OR_PRODUCTS', 'ƥޤϾʤϿƤ.');
define('TEXT_PRODUCT_MORE_INFORMATION', 'äȾܤϡξʤ<a href="http://%s" target="blank">Webڡ</a>');
define('TEXT_PRODUCT_DATE_ADDED', 'ξʤ %s ˥Ͽޤ.');
define('TEXT_PRODUCT_DATE_AVAILABLE', 'ξʤ %s ͽǤ');

define('TEXT_EDIT_INTRO', 'ɬפѹäƤ');
define('TEXT_EDIT_CATEGORIES_ID', 'ƥID:');
define('TEXT_EDIT_CATEGORIES_NAME', 'ƥ̾:');
define('TEXT_EDIT_CATEGORIES_IMAGE', 'ƥ:');
define('TEXT_EDIT_SORT_ORDER', ':');

define('TEXT_INFO_COPY_TO_INTRO', 'ξʤ򥳥ԡΥƥ򤷤Ƥ');
define('TEXT_INFO_CURRENT_CATEGORIES', 'ߤΥƥ: ');

define('TEXT_INFO_HEADING_NEW_CATEGORY', 'ƥ');
define('TEXT_INFO_HEADING_EDIT_CATEGORY', 'ƥԽ');
define('TEXT_INFO_HEADING_DELETE_CATEGORY', 'ƥ');
define('TEXT_INFO_HEADING_MOVE_CATEGORY', 'ƥư');
define('TEXT_INFO_HEADING_DELETE_PRODUCT', 'ʤ');
define('TEXT_INFO_HEADING_MOVE_PRODUCT', 'ʤư');
define('TEXT_INFO_HEADING_COPY_TO', 'ԡ');

define('TEXT_DELETE_CATEGORY_INTRO', 'Υƥ˺ޤ?');
define('TEXT_DELETE_PRODUCT_INTRO', 'ξʤ˺ޤ?');

define('TEXT_DELETE_WARNING_CHILDS', '<b>ٹ:</b> Υƥˤ %s ĤΥ֥ƥ꤬ϿƤޤ!');
define('TEXT_DELETE_WARNING_PRODUCTS', '<b>ٹ:</b> Υƥˤ %s ĤξʤϿƤޤ!');

define('TEXT_MOVE_PRODUCTS_INTRO', '<b>%s</b>ưΥƥǤ');
define('TEXT_MOVE_CATEGORIES_INTRO', '<b>%s</b>ưΥƥǤ');
define('TEXT_MOVE', '<b>%s</b>ΰư:');

define('TEXT_NEW_CATEGORY_INTRO', 'ƥξϤƤ');
define('TEXT_CATEGORIES_NAME', 'ƥ:');
define('TEXT_CATEGORIES_IMAGE', 'ƥ:');
define('TEXT_SORT_ORDER', ':');

define('TEXT_PRODUCTS_STATUS', 'ʥơ:');
define('TEXT_PRODUCTS_VIRTUAL', 'С뾦:');
define('TEXT_PRODUCTS_IS_ALWAYS_FREE_SHIPPING', '̵:');
define('TEXT_PRODUCTS_QTY_BOX_STATUS', 'ʤοɽ:');
define('TEXT_PRODUCTS_DATE_AVAILABLE', 'ȯ:');
define('TEXT_PRODUCT_AVAILABLE', '߸ˤ');
define('TEXT_PRODUCT_NOT_AVAILABLE', 'ڤ');
define('TEXT_PRODUCT_IS_VIRTUAL', 'ϤλפǤ');
define('TEXT_PRODUCT_NOT_VIRTUAL', 'λ꤬ɬפǤ');
define('TEXT_PRODUCT_IS_ALWAYS_FREE_SHIPPING', 'Ϥ̵ˤޤ');
define('TEXT_PRODUCT_NOT_ALWAYS_FREE_SHIPPING', '̾ɤǤ');

define('TEXT_PRODUCTS_QTY_BOX_STATUS_ON', 'Ϥ߸˿ɽޤ');
define('TEXT_PRODUCTS_QTY_BOX_STATUS_OFF', '߸˿ɽޤ');

define('TEXT_PRODUCTS_MANUFACTURER', '᡼:');
define('TEXT_PRODUCTS_NAME', '̾:');
define('TEXT_PRODUCTS_DESCRIPTION', 'ʤ:');
define('TEXT_PRODUCTS_QUANTITY', 'ʤκ߸˿:');
define('TEXT_PRODUCTS_MODEL', 'ʤη:');
define('TEXT_PRODUCTS_IMAGE', 'ʤβ:');
define('TEXT_PRODUCTS_IMAGE_DIR', 'åץɤǥ쥯ȥ:');
define('TEXT_PRODUCTS_URL', 'ʤURL:');
define('TEXT_PRODUCTS_URL_WITHOUT_HTTP', '<small>(\'http://\'Ϥޤ)</small>');
define('TEXT_PRODUCTS_PRICE_NET', ' (ȴ):');
define('TEXT_PRODUCTS_PRICE_GROSS', ' (ǹ):');
define('TEXT_PRODUCTS_WEIGHT', 'ʤν:');

define('EMPTY_CATEGORY', 'Υƥ');

define('TEXT_HOW_TO_COPY', 'ԡˡ:');
define('TEXT_COPY_AS_LINK', '󥯤Υԡ(¾Υƥ)');
define('TEXT_COPY_AS_DUPLICATE', 'ʣԡ(ƱΥƥ)');

define('TEXT_RESTRICT_PRODUCT_TYPE', 'ʥפ');
define('TEXT_CATEGORY_HAS_RESTRICTIONS', 'ΥƥϤξʥפ˸¤Ƥޤ');

define('ERROR_CANNOT_LINK_TO_SAME_CATEGORY', '顼: Ʊƥˤϥ󥯤Ǥޤ');
define('ERROR_CATALOG_IMAGE_DIRECTORY_NOT_WRITEABLE', '顼: ƥΥǥ쥯ȥ˽񤭹ळȤǤޤ: ' . DIR_FS_CATALOG_IMAGES);
define('ERROR_CATALOG_IMAGE_DIRECTORY_DOES_NOT_EXIST', '顼: ƥΥǥ쥯ȥ꤬¸ߤޤ: ' . DIR_FS_CATALOG_IMAGES);
define('ERROR_CANNOT_MOVE_CATEGORY_TO_PARENT', '顼: ֥ƥˤϰưǤޤ');
define('ERROR_CANNOT_MOVE_PRODUCT_TO_CATEGORY_SELF', '顼: Ʊƥ䡢ǤƱʤ¸ߤ륫ƥˤϰưǤޤ');

// Products and Attribute Copy Options
  define('TEXT_COPY_ATTRIBUTES_ONLY','ʤʣ˻Ѥ...');
  define('TEXT_COPY_ATTRIBUTES','ʥץ򥳥ԡʣޤ?');
  define('TEXT_COPY_ATTRIBUTES_YES','Ϥ');
  define('TEXT_COPY_ATTRIBUTES_NO','');

  define('TEXT_INFO_CURRENT_PRODUCT', 'ߤξ: ');
  define('TABLE_HEADING_MODEL', '');

  define('TEXT_INFO_HEADING_ATTRIBUTE_FEATURES','ʤΥץѹ ID:');
  define('TEXT_INFO_ATTRIBUTES_FEATURES_DELETE','<strong>Ƥ</strong> ʥץ:<br />');
  define('TEXT_INFO_ATTRIBUTES_FEATURES_COPY_TO','ʲξʤξʥץ¾ξʤޤΤ˥ԡ:<br />');

  define('TEXT_INFO_ATTRIBUTES_FEATURES_COPY_TO_PRODUCT','ʲξʤξʥץ<strong>¾ξ</strong>˥ԡ:<br />');
  define('TEXT_INFO_ATTRIBUTES_FEATURES_COPY_TO_CATEGORY','ʲξʤξʥץ<strong>ƥ</strong>˥ԡ:<br />');

  define('TEXT_COPY_ATTRIBUTES_CONDITIONS','<strong>ߤξʥץɤޤ?</strong>');
  define('TEXT_COPY_ATTRIBUTES_DELETE','<strong></strong>ץ򥳥ԡ');
  define('TEXT_COPY_ATTRIBUTES_UPDATE','/ʤ<strong></strong>Τɲä');
  define('TEXT_COPY_ATTRIBUTES_IGNORE','<strong>̵</strong>ƿץɲä');

  define('SUCCESS_ATTRIBUTES_DELETED','ʤΥץޤ');
  define('SUCCESS_ATTRIBUTES_UPDATE','ʤΥץ򹹿ޤ');

  define('ICON_ATTRIBUTES','ʤΥץ');

  define('TEXT_CATEGORIES_IMAGE_DIR','åץΥǥ쥯ȥ:');

  define('TEXT_VIRTUAL_PREVIEW','ٹ: С뾦ʤΤ򥹥åפޤ');
  define('TEXT_VIRTUAL_EDIT','ٹ: С뾦ʤΤ򥹥åפޤ');
  define('TEXT_FREE_SHIPPING_PREVIEW','ٹ: ̵ξʤΤ轻꤬ɬפǤ');
  define('TEXT_FREE_SHIPPING_EDIT','ٹ: ̵ξʤΤ轻꤬ɬפǤ');

  define('TEXT_PRODUCTS_QTY_BOX_STATUS_PREVIEW','ٹ: ߸̤ɽޤ󡣥ǥեȤ1Ǥ');
  define('TEXT_PRODUCTS_QTY_BOX_STATUS_EDIT','ٹ: ߸̤ɽޤ󡣥ǥեȤ1Ǥ');

  define('TEXT_PRODUCT_OPTIONS', '<strong>򤷤Ƥ:</strong>');
  define('TEXT_PRODUCT_WEIGHT_UNIT','kg');
  define('TEXT_PRODUCTS_ATTRIBUTES_INFO','ʤΥץ:');
  define('TEXT_PRODUCT_ATTRIBUTES_DOWNLOADS','ɾ: ');

  define('TEXT_PRODUCTS_PRICED_BY_ATTRIBUTES','ʥץղä:');
  define('TEXT_PRODUCT_IS_PRICED_BY_ATTRIBUTE','Yes');
  define('TEXT_PRODUCT_NOT_PRICED_BY_ATTRIBUTE','No');
  define('TEXT_PRODUCTS_PRICED_BY_ATTRIBUTES_PREVIEW','*ɽʤϺǤʤ㤤ʤΥץޤ᤿ʤˤʤޤ');
  define('TEXT_PRODUCTS_PRICED_BY_ATTRIBUTES_EDIT','*ɽʤϺǤʤ㤤ʤΥץޤ᤿ʤˤʤޤ');

  define('TEXT_PRODUCTS_QUANTITY_MIN_RETAIL','ǾĿ:');
  define('TEXT_PRODUCTS_QUANTITY_UNITS_RETAIL','ñ:');
  define('TEXT_PRODUCTS_QUANTITY_MAX_RETAIL','Ŀ:');

  define('TEXT_PRODUCTS_QUANTITY_MAX_RETAIL_EDIT','0 = ̵¡1 = ̥ܥåäޤʾξϤοޤʸǤ褦ˤʤޤ');

  define('TEXT_PRODUCTS_MIXED','ñ̤ǾĿȤư:');

  define('TEXT_PRODUCT_IS_FREE','̵ξ:');
  define('TEXT_PRODUCTS_IS_FREE_PREVIEW','*ξʤ̵ꤵƤޤ');
  define('TEXT_PRODUCTS_IS_FREE_EDIT','*ξʤ̵ꤵƤޤ');

  define('TEXT_PRODUCT_IS_CALL','ʤ䤤碌ʤˤ:');
  define('TEXT_PRODUCTS_IS_CALL_PREVIEW','*ξʤϲʤ䤤碌ʤꤵƤޤ');
  define('TEXT_PRODUCTS_IS_CALL_EDIT','*ξʤϲʤ䤤碌ʤꤵƤޤ');

  define('TEXT_ATTRIBUTE_COPY_SKIPPING','<strong>ץ򥹥åפޤ</strong>');
  define('TEXT_ATTRIBUTE_COPY_INSERTING','<strong>ץޤ</strong>');
  define('TEXT_ATTRIBUTE_COPY_UPDATING','<strong>ץ򹹿ޤ </strong>');

  define('TEXT_SHIPPING_INFO',
  '<strong>С뾦</strong> ϡ֥ӥפ' . TEXT_GV_NAMES . 'פΤ褦轻ɬפ̵ΤǤ<br />' .
  '<strong>̵</strong> ɬפʤ轻꤬ɬפʤΤǤ<br />' .
  '<strong>ɾ</strong> ϥС뾦ʤǤΤǡξȤޡɬפϤޤ<br />'
  );

  define('TEXT_ANY_TYPE', 'ΥפǤ');
  define('TABLE_HEADING_PRODUCT_TYPES', 'ʥ');

// categories status
define('TEXT_INFO_HEADING_STATUS_CATEGORY', 'ʲΥƥΥơѤ:');
define('TEXT_CATEGORIES_STATUS_INTRO', 'ƥΥơʲѤ: ');
define('TEXT_CATEGORIES_STATUS_OFF', '');
define('TEXT_CATEGORIES_STATUS_ON', '');
define('TEXT_PRODUCTS_STATUS_INFO', 'ʤΥơʲѤ: ');
define('TEXT_PRODUCTS_STATUS_OFF', '');
define('TEXT_PRODUCTS_STATUS_ON', '');
define('TEXT_PRODUCTS_STATUS_NOCHANGE', 'ѹʤ');
define('TEXT_CATEGORIES_STATUS_WARNING', '<strong>ٹ...</strong><br />: ƥ̵ˤȡΥƥ°ʤ̵ˤʤޤΥƥˤꡢ¾Υƥ˥󥯤Ƥ뾦ʤ̵ˤʤޤ');

define('TEXT_PRODUCTS_STATUS_ON_OF',' of ');
define('TEXT_PRODUCTS_STATUS_ACTIVE',' ƥ ');

define('TEXT_CATEGORIES_DESCRIPTION', 'ƥ:');
?>

==> zen-cart-v1.3.0.2-l10n-jp-5.zip: zen-cart-v1.3.0.2-l10n-jp-5/admin/includes/languages/japanese/categories.php <==
<?php
//
// +----------------------------------------------------------------------+
// |zen-cart Open Source E-commerce                                       |
// +----------------------------------------------------------------------+
// | Copyright (c) 2003 The zen-cart developers                           |
// |                                                                      |
// | http://www.zen-cart.com/index.php                                    |
// |                                                                      |
// | Portions Copyright (c) 2003 osCommerce                               |
// +----------------------------------------------------------------------+
// | This source file is subject to version 2.0 of the GPL license,       |
// | that is bundled with this package in the file LICENSE, and is        |
// | available through the world-wide-web at the following url:           |
// | http://www.zen-cart.com/license/2_0.txt.                             |
// | If you did not receive a copy of the zen-cart license and are unable |
// | to obtain it through the world-wide-web, please send a note to       |
// | license@zen-cart.com so we can mail you a copy immediately.          |
// +----------------------------------------------------------------------+
//  $Id: categories.php 2847 2006-01-13 07:40:50Z drbyte $
//

define('HEADING_TITLE', 'ƥꡦʤδ');
define('HEADING_TITLE_GOTO', ':');

define('TABLE_HEADING_ID', 'ID');
define('TABLE_HEADING_CATEGORIES_PRODUCTS', 'ƥ / ');
define('TABLE_HEADING_CATEGORIES_SORT_ORDER', 'Sort');

define('TABLE_HEADING_PRICE','/ò/');
define('TABLE_HEADING_QUANTITY','');

define('TABLE_HEADING_ACTION', '');
define('TABLE_HEADING_STATUS', 'ơ');

define('TEXT_CATEGORIES', 'ƥ:');
define('TEXT_SUBCATEGORIES', '֥ƥ:');
define('TEXT_PRODUCTS', ':');
define('TEXT_PRODUCTS_PRICE_INFO', ':');
define('TEXT_PRODUCTS_TAX_CLASS', 'Ǽ:');
define('TEXT_PRODUCTS_AVERAGE_RATING', 'ʿ:');
define('TEXT_PRODUCTS_QUANTITY_INFO', ':');
define('TEXT_DATE_ADDED', 'Ͽ:');
define('TEXT_DATE_AVAILABLE', 'ȯ:');
define('TEXT_LAST_MODIFIED', ':');
define('TEXT_IMAGE_NONEXISTENT', '¸ߤޤ');
define('TEXT_NO_CHILD_CATEGORIES_OR_PRODUCTS', 'ƥޤϾʤϿƤ.');
define('TEXT_PRODUCT_MORE_INFORMATION', 'äȾܤϡξʤ<a href="http://%s" target="blank">Webڡ</a>');
define('TEXT_PRODUCT_DATE_ADDED', 'ξʤ %s ˥Ͽޤ.');
define('TEXT_PRODUCT_DATE_AVAILABLE', 'ξʤ %s ͽǤ');

define('TEXT_EDIT_INTRO', 'ɬפѹäƤ');
define('TEXT_EDIT_CATEGORIES_ID', 'ƥID:');
define('TEXT_EDIT_CATEGORIES_NAME', 'ƥ̾:');
define('TEXT_EDIT_CATEGORIES_IMAGE', 'ƥ:');
define('TEXT_EDIT_SORT_ORDER', ':');

define('TEXT_INFO_COPY_TO_INTRO', 'ξʤ򥳥ԡΥƥ򤷤Ƥ');
define('TEXT_INFO_CURRENT_CATEGORIES', 'ߤΥƥ: ');

define('TEXT_INFO_HEADING_NEW_CATEGORY', 'ƥ');
define('TEXT_INFO_HEADING_EDIT_CATEGORY', 'ƥԽ');
define('TEXT_INFO_HEADING_DELETE_CATEGORY', 'ƥ');
define('TEXT_INFO_HEADING_MOVE_CATEGORY', 'ƥư');
define('TEXT_INFO_HEADING_DELETE_PRODUCT', 'ʤ');
define('TEXT_INFO_HEADING_MOVE_PRODUCT', 'ʤư');
define('TEXT_INFO_HEADING_COPY_TO', 'ԡ');

define('TEXT_DELETE_CATEGORY_INTRO', 'Υƥ˺ޤ?');
define('TEXT_DELETE_PRODUCT_INTRO', 'ξʤ˺ޤ?');

define('TEXT_DELETE_WARNING_CHILDS', '<b>ٹ:</b> Υƥˤ %s ĤΥ֥ƥ꤬ϿƤޤ!');
define('TEXT_DELETE_WARNING_PRODUCTS', '<b>ٹ:</b> Υƥˤ %s ĤξʤϿƤޤ!');

define('TEXT_MOVE_PRODUCTS_INTRO', '<b>%s</b>ưΥƥǤ');
define('TEXT_MOVE_CATEGORIES_INTRO', '<b>%s</b>ưΥƥǤ');
define('TEXT_MOVE', '<b>%s</b>ΰư:');

define('TEXT_NEW_CATEGORY_INTRO', 'ƥξϤƤ');
define('TEXT_CATEGORIES_NAME', 'ƥ:');
define('TEXT_CATEGORIES_IMAGE', 'ƥ:');
define('TEXT_SORT_ORDER', ':');

define('TEXT_PRODUCTS_STATUS', 'ʥơ:');
define('TEXT_PRODUCTS_VIRTUAL', 'С뾦:');
define('TEXT_PRODUCTS_IS_ALWAYS_FREE_SHIPPING', '̵:');
define('TEXT_PRODUCTS_QTY_BOX_STATUS', 'ʤοɽ:');
define('TEXT_PRODUCTS_DATE_AVAILABLE', 'ȯ:');
define('TEXT_PRODUCT_AVAILABLE', '߸ˤ');
define('TEXT_PRODUCT_NOT_AVAILABLE', 'ڤ');
define('TEXT_PRODUCT_IS_VIRTUAL', 'ϤλפǤ');
define('TEXT_PRODUCT_NOT_VIRTUAL', 'λ꤬ɬפǤ');
define('TEXT_PRODUCT_IS_ALWAYS_FREE_SHIPPING', 'Ϥ̵ˤޤ');
define('TEXT_PRODUCT_NOT_ALWAYS_FREE_SHIPPING', '̾ɤǤ');

define('TEXT_PRODUCTS_QTY_BOX_STATUS_ON', 'Ϥ߸˿ɽޤ');
define('TEXT_PRODUCTS_QTY_BOX_STATUS_OFF', '߸˿ɽޤ');

define('TEXT_PRODUCTS_MANUFACTURER', '᡼:');
define('TEXT_PRODUCTS_NAME', '̾:');
define('TEXT_PRODUCTS_DESCRIPTION', 'ʤ:');
define('TEXT_PRODUCTS_QUANTITY', 'ʤκ߸˿:');
define('TEXT_PRODUCTS_MODEL', 'ʤη:');
define('TEXT_PRODUCTS_IMAGE', 'ʤβ:');
define('TEXT_PRODUCTS_IMAGE_DIR', 'åץɤǥ쥯ȥ:');
define('TEXT_PRODUCTS_URL', 'ʤURL:');
define('TEXT_PRODUCTS_URL_WITHOUT_HTTP', '<small>(\'http://\'Ϥޤ)</small>');
define('TEXT_PRODUCTS_PRICE_NET', ' (ȴ):');
define('TEXT_PRODUCTS_PRICE_GROSS', ' (ǹ):');
define('TEXT_PRODUCTS_WEIGHT', 'ʤν:');

define('EMPTY_CATEGORY', 'Υƥ');

define('TEXT_HOW_TO_COPY', 'ԡˡ:');
define('TEXT_COPY_AS_LINK', '󥯤Υԡ(¾Υƥ)');
define('TEXT_COPY_AS_DUPLICATE', 'ʣԡ(ƱΥƥ)');

define('TEXT_RESTRICT_PRODUCT_TYPE', 'ʥפ');
define('TEXT_CATEGORY_HAS_RESTRICTIONS', 'ΥƥϤξʥפ˸¤Ƥޤ');
define('ERROR_CANNOT_ADD_PRODUCT_TYPE','ΥפξϤΥƥ꡼ˤɲäǤޤ󡣥ƥ꡼»åƤߤƤ');

// Products and Attribute Copy Options
  define('TEXT_COPY_ATTRIBUTES_ONLY','ʤʣ˻Ѥ...');
  define('TEXT_COPY_ATTRIBUTES','ʥץ򥳥ԡʣޤ?');
  define('TEXT_COPY_ATTRIBUTES_YES','Ϥ');
  define('TEXT_COPY_ATTRIBUTES_NO','');

  define('TEXT_INFO_CURRENT_PRODUCT', 'ߤξ: ');
  define('TABLE_HEADING_MODEL', '');

  define('TEXT_INFO_HEADING_ATTRIBUTE_FEATURES','ʤΥץѹ ID:');
  define('TEXT_INFO_ATTRIBUTES_FEATURES_DELETE','<strong>Ƥ</strong> ʥץ:<br />');
  define('TEXT_INFO_ATTRIBUTES_FEATURES_COPY_TO','ʲξʤξʥץ¾ξʤޤΤ˥ԡ:<br />');

  define('TEXT_INFO_ATTRIBUTES_FEATURES_COPY_TO_PRODUCT','ʲξʤξʥץ<strong>¾ξ</strong>˥ԡ:<br />');
  define('TEXT_INFO_ATTRIBUTES_FEATURES_COPY_TO_CATEGORY','ʲξʤξʥץ<strong>ƥ</strong>˥ԡ:<br />');

  define('TEXT_COPY_ATTRIBUTES_CONDITIONS','<strong>ߤξʥץɤޤ?</strong>');
  define('TEXT_COPY_ATTRIBUTES_DELETE','<strong></strong>ץ򥳥ԡ');
  define('TEXT_COPY_ATTRIBUTES_UPDATE','/ʤ<strong></strong>Τɲä');
  define('TEXT_COPY_ATTRIBUTES_IGNORE','<strong>̵</strong>ƿץɲä');

  define('SUCCESS_ATTRIBUTES_DELETED','ʤΥץޤ');
  define('SUCCESS_ATTRIBUTES_UPDATE','ʤΥץ򹹿ޤ');

  define('ICON_ATTRIBUTES','ʤΥץ');

  define('TEXT_CATEGORIES_IMAGE_DIR','åץΥǥ쥯ȥ:');

  define('TEXT_VIRTUAL_PREVIEW','ٹ: С뾦ʤΤ򥹥åפޤ');
  define('TEXT_VIRTUAL_EDIT','ٹ: С뾦ʤΤ򥹥åפޤ');
  define('TEXT_FREE_SHIPPING_PREVIEW','ٹ: ̵ξʤΤ轻꤬ɬפǤ');
  define('TEXT_FREE_SHIPPING_EDIT','ٹ: ̵ξʤΤ轻꤬ɬפǤ');

  define('TEXT_PRODUCTS_QTY_BOX_STATUS_PREVIEW','ٹ: ߸̤ɽޤ󡣥ǥեȤ1Ǥ');
  define('TEXT_PRODUCTS_QTY_BOX_STATUS_EDIT','ٹ: ߸̤ɽޤ󡣥ǥեȤ1Ǥ');

  define('TEXT_PRODUCT_OPTIONS', '<strong>򤷤Ƥ:</strong>');
  define('TEXT_PRODUCTS_ATTRIBUTES_INFO','ʤΥץ:');
  define('TEXT_PRODUCT_ATTRIBUTES_DOWNLOADS','ɾ: ');


  define('TEXT_PRODUCTS_PRICED_BY_ATTRIBUTES','ʥץղä:');
  define('TEXT_PRODUCT_IS_PRICED_BY_ATTRIBUTE','Ϥ');
  define('TEXT_PRODUCT_NOT_PRICED_BY_ATTRIBUTE','');
  define('TEXT_PRODUCTS_PRICED_BY_ATTRIBUTES_PREVIEW','*ɽʤϺǤʤ㤤ʤΥץޤ᤿ʤˤʤޤ');
  define('TEXT_PRODUCTS_PRICED_BY_ATTRIBUTES_EDIT','*ɽʤϺǤʤ㤤ʤΥץޤ᤿ʤˤʤޤ');

  define('TEXT_PRODUCTS_QUANTITY_MIN_RETAIL','ǾĿ:');
  define('TEXT_PRODUCTS_QUANTITY_UNITS_RETAIL','ñ:');
  define('TEXT_PRODUCTS_QUANTITY_MAX_RETAIL','Ŀ:');

  define('TEXT_PRODUCTS_QUANTITY_MAX_RETAIL_EDIT','0 = ̵¡1 = ̥ܥåäޤʾξϤοޤʸǤ褦ˤʤޤ');

  define('TEXT_PRODUCTS_MIXED','ñ̤ǾĿȤư:');

  define('PRODUCTS_PRICE_IS_FREE_TEXT', 'ʤ̵');
  define('TEXT_PRODUCT_IS_FREE','̵ξ:');
  define('TEXT_PRODUCTS_IS_FREE_PREVIEW','*ξʤ̵ꤵƤޤ');
  define('TEXT_PRODUCTS_IS_FREE_EDIT','*ξʤ̵ꤵƤޤ');

  define('TEXT_PRODUCT_IS_CALL','ʤ䤤碌ʤˤ:');
  define('TEXT_PRODUCTS_IS_CALL_PREVIEW','*ξʤϲʤ䤤碌ʤꤵƤޤ');
  define('TEXT_PRODUCTS_IS_CALL_EDIT','*ξʤϲʤ䤤碌ʤꤵƤޤ');

  define('TEXT_ATTRIBUTE_COPY_SKIPPING','<strong>ץ򥹥åפޤ</strong>');
  define('TEXT_ATTRIBUTE_COPY_INSERTING','<strong>ץޤ</strong>');
  define('TEXT_ATTRIBUTE_COPY_UPDATING','<strong>ץ򹹿ޤ </strong>');

  define('TEXT_SHIPPING_INFO',
  '<strong>С뾦</strong> ϡ֥ӥפ' . TEXT_GV_NAMES . 'פΤ褦轻ɬפ̵ΤǤ<br />' .
  '<strong>̵</strong> ɬפʤ轻꤬ɬפʤΤǤ<br />' .
  '<strong>ɾ</strong> ϥС뾦ʤǤΤǡξȤޡɬפϤޤ<br />'
  );

  define('TEXT_ANY_TYPE', 'ΥפǤ');
  define('TABLE_HEADING_PRODUCT_TYPES', 'ʥ');

// categories status
define('TEXT_INFO_HEADING_STATUS_CATEGORY', 'ʲΥƥΥơѤ:');
define('TEXT_CATEGORIES_STATUS_INTRO', 'ƥΥơʲѤ: ');
define('TEXT_CATEGORIES_STATUS_OFF', '');
define('TEXT_CATEGORIES_STATUS_ON', '');
define('TEXT_PRODUCTS_STATUS_INFO', 'ʤΥơʲѤ: ');
define('TEXT_PRODUCTS_STATUS_OFF', '');
define('TEXT_PRODUCTS_STATUS_ON', '');
define('TEXT_PRODUCTS_STATUS_NOCHANGE', 'ѹʤ');
define('TEXT_CATEGORIES_STATUS_WARNING', '<strong>ٹ...</strong><br />: ƥ̵ˤȡΥƥ°ʤ̵ˤʤޤΥƥˤꡢ¾Υƥ˥󥯤Ƥ뾦ʤ̵ˤʤޤ');

define('TEXT_PRODUCTS_STATUS_ON_OF','  ');
define('TEXT_PRODUCTS_STATUS_ACTIVE',' ƥ ');

define('TEXT_CATEGORIES_DESCRIPTION', 'ƥ:');
define('PRODUCTS_PRICE_IS_CALL_FOR_PRICE_TEXT', '䤤碌ξ');

// Metatags
  define('TEXT_INFO_HEADING_EDIT_CATEGORY_META_TAGS', 'ƥΥإå');
  define('TEXT_EDIT_CATEGORIES_META_TAGS_INTRO', 'إåΥޥ');
  define('TEXT_EDIT_CATEGORIES_META_TAGS_TITLE', 'ȥ:');
  define('TEXT_EDIT_CATEGORIES_META_TAGS_KEYWORDS', 'Meta(Keywords):');
  define('TEXT_EDIT_CATEGORIES_META_TAGS_DESCRIPTION', 'Meta(Description):');




?>
